@@ -1,7 +1,7 @@
 #############################################################################
 #
 # XLConnect
-# Copyright (C) 2010-2012 Mirai Solutions GmbH
+# Copyright (C) 2010-2013 Mirai Solutions GmbH
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -66,8 +66,8 @@ test.dataframeConversion <- function() {
 	
 	# custom test dataset
 	cdf <- data.frame(
-			"Column.A" = c(1, 2, 3, NA, 5, 6, 7, 8, NA, 10),
-			"Column.B" = c(-4, -3, NA, -1, 0, NA, NA, 3, 4, 5),
+			"Column.A" = c(1, 2, 3, NA, 5, Inf, 7, 8, NA, 10),
+			"Column.B" = c(-4, -3, NA, -Inf, 0, NA, NA, 3, 4, 5),
 			"Column.C" = c("Anna", "???", NA, "", NA, "$!?&%", "(?2@?~?'^*#|)", "{}[]:,;-_<>", "\\sadf\n\nv", "a b c"),
 			"Column.D" = c(pi, -pi, NA, sqrt(2), sqrt(0.3), -sqrt(pi), exp(1), log(2), sin(2), -tan(2)),
 			"Column.E" = c(TRUE, TRUE, NA, NA, FALSE, FALSE, TRUE, NA, FALSE, TRUE),
