@@ -26,8 +26,11 @@
 #
 #############################################################################
 
-# Limit number of GC threads
-options(java.parameters = c("-XX:+UseParallelGC", "-XX:ParallelGCThreads=1"))
+# Set timezone to UTC
+Sys.setenv("TZ" = "UTC")
+
+# Limit number of GC threads; set timezone
+options(java.parameters = c("-XX:+UseParallelGC", "-XX:ParallelGCThreads=1", paste0("-Duser.timezone=", Sys.timezone())))
 
 # Load library built by R CMD check
 library(package = "XLConnect", character.only = TRUE)
